@@ -28,6 +28,8 @@
 
 #include "visir_recipe.h"
 #include "irplib_framelist.h"
+#include "visir_spc_optmod.h"
+#include "visir_spectro.h"
 #include "irplib_wcs.h"
 #include <cxlist.h>
 /* Verify self-sufficiency of CPL header files by including system files last */
@@ -107,6 +109,7 @@ typedef struct {
     double pxspace;
     double pfov;
     cpl_wcs * wcs;
+    visir_spc_resol resol;
 
     /* only for burst */
     int to_off;
@@ -644,6 +647,26 @@ repack_framestate_new(irplib_framelist * rawframes, int iframe,
                  "Jitterwidth %g", state->posang * CPL_MATH_DEG_RAD, state->offsetx,
                  state->offsety, state->pthrow, state->jitterwidth);
 
+    const char * sresol = visir_pfits_get_resol(state->plist);
+    if (sresol && strcmp(sresol, "LRP") == 0) {
+        state->resol = VISIR_SPC_R_LRP;
+    }
+    else if (sresol && strcmp(sresol, "LR") == 0) {
+        state->resol = VISIR_SPC_R_LR;
+    }
+    else if (sresol && strcmp(sresol, "MR") == 0) {
+        state->resol = VISIR_SPC_R_MR;
+    }
+    else if (sresol && strcmp(sresol, "HRS") == 0) {
+        state->resol = VISIR_SPC_R_HR;
+    }
+    else if (sresol && strcmp(sresol, "HRG") == 0) {
+        state->resol = VISIR_SPC_R_GHR;
+    }
+    else {
+        state->resol = VISIR_SPC_R_ERR;
+    }
+
     {
         long nx, ny;
         if (state->datatype == VISIR_DATA_AQU_HCYCLE ||
@@ -938,12 +961,6 @@ static int visir_util_repack(cpl_frameset            * framelist,
 
     {
         cpl_frame * frm = cpl_frameset_find(framelist, VISIR_CALIB_STATIC_MASK);
-        if (!frm) {
-            frm = cpl_frameset_find(framelist, VISIR_CALIB_STATIC_MASK_IMG);
-        }
-        if (!frm) {
-            frm = cpl_frameset_find(framelist, VISIR_CALIB_STATIC_MASK_SPC);
-        }
         repack_framestate * state = ((repack_framestate*)cx_list_front(alist));
         if (frm) {
             bpm = visir_load_bpm(frm, state->datatype,
@@ -1694,16 +1711,25 @@ chop_correct(const repack_framestate * state,
  * @brief compute sum of median of each image
  *
  * @param list    imagelist
+ * @param llx     lower left x window (FITS)
+ * @param lly     lower left y window (FITS)
+ * @param urx     upper right x window (FITS)
+ * @param ury     upper right y window (FITS)
  * @param nimages number of images summed added to this variable
  */
 /* ---------------------------------------------------------------------------*/
 static double
-compute_qc_median(const cpl_imagelist * list, cpl_size * nimages)
+compute_qc_median(const cpl_imagelist * list, cpl_size * nimages,
+                  cpl_size llx, cpl_size lly, cpl_size urx, cpl_size ury)
 {
     double sum = 0.;
     for (cpl_size i = 0; i < cpl_imagelist_get_size(list); i++) {
         const cpl_image * img = cpl_imagelist_get_const(list, i);
-        sum += cpl_image_get_median(img);
+        llx = CPL_MIN(cpl_image_get_size_x(img), llx);
+        lly = CPL_MIN(cpl_image_get_size_y(img), lly);
+        urx = CPL_MIN(cpl_image_get_size_x(img), urx);
+        ury = CPL_MIN(cpl_image_get_size_y(img), ury);
+        sum += cpl_image_get_median_window(img, llx, lly, urx, ury);
     }
 
     *nimages += cpl_imagelist_get_size(list);
@@ -1921,13 +1947,24 @@ visir_util_repack_two(const repack_framestate * fstatea,
         }
         OMP3_PRAGMA(omp taskwait);
     }
-    if ((visir_data_is_aqu(state->datatype) || visir_data_is_burst(state->datatype)) &&
+    if ((visir_data_is_aqu(state->datatype) ||
+         visir_data_is_burst(state->datatype)) &&
         state->datatype != VISIR_DATA_AQU_INT) {
         /* cube2 is computed in prepare_output */
-        qc_bkg_sum += compute_qc_median(aon,  &qc_bkg_count);
-        qc_bkg_sum += compute_qc_median(aoff, &qc_bkg_count);
-        qc_bkg_sum += compute_qc_median(bon,  &qc_bkg_count);
-        qc_bkg_sum += compute_qc_median(boff, &qc_bkg_count);
+        cpl_size llx = 1, lly = 1, urx = 1000000, ury = 1000000;
+        /* limit wavelength (PIPE-6744) aqu LR wavelength decreasing in x */
+        if (state->resol == VISIR_SPC_R_LRP) {
+            llx = 1024 - VISIR_AQU_APPROX_WLEN13;
+            urx = 1024 - VISIR_AQU_APPROX_WLEN8;
+        }
+        qc_bkg_sum += compute_qc_median(aon,  &qc_bkg_count,
+                                        llx, lly, urx, ury);
+        qc_bkg_sum += compute_qc_median(aoff, &qc_bkg_count,
+                                        llx, lly, urx, ury);
+        qc_bkg_sum += compute_qc_median(bon,  &qc_bkg_count,
+                                        llx, lly, urx, ury);
+        qc_bkg_sum += compute_qc_median(boff, &qc_bkg_count,
+                                        llx, lly, urx, ury);
     }
 
 
