@@ -329,7 +329,10 @@ class DataPlotterManager:
         elif self.plt['av'].inaxes(event):
             self.showing = self.SHOW_SLICE
             for c in self.rad.circles:
-                c.set_facecolor(self.plt['stats'].ax.get_axis_bgcolor())
+                try:
+                    c.set_facecolor(self.plt['stats'].ax.get_facecolor())
+                except AttributeError:
+                    c.set_facecolor(self.plt['stats'].ax.get_axis_bgcolor())
             x, y = int(event.ydata), int(event.xdata)
             self.plt['stats'].set_loading()
             Future(self.get_slice, args=(self.fits['BKG_CORRECTED'], x, y),
@@ -466,7 +469,10 @@ class DataPlotterManager:
             if l.get_text() == label:
                 self.rad.circles[i].set_facecolor(self.rad.activecolor)
             else:
-                self.rad.circles[i].set_facecolor(plt_stats.ax.get_axis_bgcolor())
+                try:
+                    self.rad.circles[i].set_facecolor(plt_stats.ax.get_facecolor())
+                except AttributeError:
+                    self.rad.circles[i].set_facecolor(plt_stats.ax.get_axis_bgcolor())
 
         plt_stats.draw()
 
