@@ -31,8 +31,8 @@
 #include	"config.h"
 #endif
 
-#ifndef _POSIX_SOURCE
-#define _POSIX_SOURCE /* for fileno */
+#ifndef _POSIX_C_SOURCE
+#define _POSIX_C_SOURCE 200112L /* for fileno */
 #endif
 
 #include	<stdio.h>
