@@ -1,4 +1,4 @@
-/* $Id: irplib_pfits.c,v 1.14 2007/08/08 09:34:43 llundin Exp $
+/* $Id: irplib_pfits.c,v 1.15 2013-05-13 16:05:04 jtaylor Exp $
  *
  * This file is part of the IRPLIB Package
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: llundin $
- * $Date: 2007/08/08 09:34:43 $
- * $Revision: 1.14 $
- * $Name: visir-3_5_1 $
+ * $Author: jtaylor $
+ * $Date: 2013-05-13 16:05:04 $
+ * $Revision: 1.15 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -33,17 +33,16 @@
                                    Includes
  -----------------------------------------------------------------------------*/
 
+#include "irplib_utils.h"
+#include "irplib_pfits.h"
+
+#include <cpl.h>
+
+#include <assert.h>
 #include <string.h>
 #include <sys/types.h>
 #include <regex.h>
 
-#include <assert.h>
-#include <cpl.h>
-
-#include "irplib_utils.h"
-#include "irplib_tools.h"
-#include "irplib_pfits.h"
-
 /*-----------------------------------------------------------------------------
                                  Private funcions
  -----------------------------------------------------------------------------*/
@@ -410,7 +409,7 @@ cpl_error_code irplib_pfits_set_airmass(cpl_propertylist * self,
         const char * key = "AIRMASS";
         const char * comment = cpl_propertylist_get_comment(self, key);
 
-        irplib_error_recover(prestate, "Could not get FITS key:");
+        cpl_errorstate_set(prestate);
 
         airmass /= (double)nmass;
         
@@ -457,7 +456,6 @@ static cpl_error_code irplib_dfs_check_frame_tag(const cpl_frame * self,
 
     const char   * file;
     const char   * tag;
-    const char   * docatg;
     const char   * catg;
     const char   * type;
     const char   * tech;
@@ -486,6 +484,7 @@ static cpl_error_code irplib_dfs_check_frame_tag(const cpl_frame * self,
         }                              
         cpl_errorstate_set(prestate);
     } else {
+        const char   * docatg;
 
         cpl_ensure_code(pfind != NULL, CPL_ERROR_NULL_INPUT);
 
