@@ -55,6 +55,7 @@ static cpl_bivector * visir_spc_phot_model_from_cat(const char *, double,
 static int visir_spc_phot_model_rebin(const cpl_bivector *, cpl_table *);
 
 static cpl_error_code visir_spc_sens_stat(const visir_spc_config *,
+                                          const visir_spc_resol,
                                           double *, double *, double *,
                                           const cpl_table *);
 
@@ -68,6 +69,24 @@ static cpl_error_code visir_spc_phot_qc(cpl_propertylist *,
  */
 /*----------------------------------------------------------------------------*/
 
+/*-----------------------------------------------------------------------------
+                               Defines
+ -----------------------------------------------------------------------------*/
+
+/* For QC wavelenghts less than this one are ignored */
+#ifndef VISIR_WAVELEN_QC_MIN
+#define VISIR_WAVELEN_QC_MIN 8e-6
+#endif
+/* For QC wavelenghts greater than this one are ignored */
+#ifndef VISIR_WAVELEN_QC_MAX
+#define VISIR_WAVELEN_QC_MAX 13e-6
+#endif
+
+/* Minimum number of spectral values to ignore, from each end */
+#ifndef VISIR_WAVELEN_QC_IGNORE
+#define VISIR_WAVELEN_QC_IGNORE 3
+#endif
+
 /**@{*/
 
 
@@ -81,6 +100,7 @@ static cpl_error_code visir_spc_phot_qc(cpl_propertylist *,
   @param    pweight2d      2D weights image to be created or NULL on error
   @param    qclist         QC Properties are appended to this list
   @param    spc_table      The Spectral Table
+  @param    resol          Resolution
   @param    dit_key        The key of the DIT card
   @return   a table or NULL on error
   @see visir_spc_phot_sensit2()
@@ -94,6 +114,7 @@ visir_spc_phot_sensit(const irplib_framelist * rawframes,
                       cpl_image   ** pweight2d,
                       cpl_propertylist * qclist,
                       cpl_table *   spc_table,
+                      const visir_spc_resol resol,
                       const char * dit_key)
 
 {
@@ -196,7 +217,8 @@ visir_spc_phot_sensit(const irplib_framelist * rawframes,
         }
     }
 
-    skip_if(visir_spc_sens_stat(pconfig, &sens_median, &sens_mean, &sens_stdev, spc_table));
+    skip_if(visir_spc_sens_stat(pconfig, resol, &sens_median, &sens_mean,
+                                &sens_stdev, spc_table));
 
     /* This column is not part of the product */
     skip_if (cpl_table_erase_column(spc_table, "SPC_EMISSIVITY"));
@@ -348,7 +370,7 @@ visir_spc_phot_sensit_from_image(cpl_image    ** combined,
                                     visir_data_is_aqu(dtype)));
 
     visir_spc_phot_sensit(rawframes, pconfig, plist, star_cat, pweight2d,
-                          qclist, spc_table, dit_key);
+                          qclist, spc_table, resol, dit_key);
 
     cpl_imagelist_delete(hcycle);
     hcycle = NULL;
@@ -563,18 +585,71 @@ static int visir_spc_phot_model_rebin(
     return cpl_error_get_code();
 }
 
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    Find index of first and last wavelengths to use for QC params
+  @param    self   The Spectral Table
+  @param    pstart The index of the first element to use, or unchanged on error
+  @param    pend  The index of the last element to use, or unchanged on error
+  @return   CPL_ERROR_NONE or the relevant #_cpl_error_code_
+  @note     If the input spectrum has no values in the hardcoded interval the
+            CPL_DATA_NOT_FOUND error is returned.
+ */
+/*----------------------------------------------------------------------------*/
+static cpl_error_code visir_spc_wl_start_end(const cpl_table * self,
+                                             cpl_size * pstart, cpl_size * pend)
+{
+    const cpl_size npix = cpl_table_get_nrow(self);
+    cpl_vector * vwave = NULL;
+
+    /* FIXME: Use cpl_table_select() */
+    /* vwave will _not_ be modified */
+    IRPLIB_DIAG_PRAGMA_PUSH_IGN(-Wcast-qual);
+    vwave = cpl_vector_wrap(npix, (double*)
+                            cpl_table_get_data_double_const(self, "WLEN"));
+    IRPLIB_DIAG_PRAGMA_POP;
+
+    assert(VISIR_WAVELEN_QC_MIN < VISIR_WAVELEN_QC_MAX);
+
+    cpl_size l = visir_lower_bound(vwave, VISIR_WAVELEN_QC_MIN);
+    cpl_size u = visir_upper_bound(vwave, VISIR_WAVELEN_QC_MAX);
+
+    l = CPL_MAX(l, VISIR_WAVELEN_QC_IGNORE);
+    u = CPL_MIN(u, npix - VISIR_WAVELEN_QC_IGNORE);
+
+    if (u - l <= 0) {
+        (void)cpl_error_set_message(cpl_func, CPL_ERROR_DATA_NOT_FOUND,
+                                    "For QC the calibrated wavelength range "
+                                    "(%g, %g) does not intersect with the "
+                                    "required (%g, %g) [m]",
+                                    cpl_vector_get(vwave, l),
+                                    cpl_vector_get(vwave, u),
+                                    VISIR_WAVELEN_QC_MIN, VISIR_WAVELEN_QC_MAX);
+    } else {
+        *pstart = l;
+        *pend  = u;
+    }
+
+    cpl_vector_unwrap(vwave);
+
+    return cpl_error_get_code();
+}
+
+
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Compute some statistics on the sensitivity
-  @param    pconfig     The config struct
+  @param    pconfig      The config struct
+  @param    resol        Resolution
   @param    psens_median The median of the sensitivity (over the wavelenghts)
   @param    psens_mean   The mean of the sensitivity (over the wavelenghts)
   @param    psens_stdev  The stdev of the sensitivity (over the wavelenghts)
-  @param    spc_table   The Spectral Table
+  @param    spc_table    The Spectral Table
   @return   CPL_ERROR_NONE or the relevant #_cpl_error_code_
  */
 /*----------------------------------------------------------------------------*/
 static cpl_error_code visir_spc_sens_stat(const visir_spc_config * pconfig,
+                                          const visir_spc_resol resol,
                                           double * psens_median,
                                           double * psens_mean,
                                           double * psens_stdev,
@@ -584,23 +659,36 @@ static cpl_error_code visir_spc_sens_stat(const visir_spc_config * pconfig,
     cpl_vector * sens_ignore = NULL;
     cpl_vector * sens_mini = NULL;
     double       emis_min, emis_max;
-    const int    npix = cpl_table_get_nrow(spc_table);
-    const int    npix_ignore = 3;
-    int i;
+    cpl_size          npix_start = 0;
+    cpl_size          npix_end = 0;
+    cpl_size          nuse;
     int iok;
 
     skip_if(0);
 
     skip_if(pconfig  == NULL);
 
+    if (resol == VISIR_SPC_R_LRP || resol == VISIR_SPC_R_LR) {
+        skip_if(visir_spc_wl_start_end(spc_table, &npix_start, &npix_end));
+    } else {
+        npix_start = VISIR_WAVELEN_QC_IGNORE;
+        npix_end = cpl_table_get_nrow(spc_table) - VISIR_WAVELEN_QC_IGNORE;
+    }
+
+    nuse = npix_end - npix_start;
+
+    cpl_msg_info(cpl_func, "QC computed from %lld spectral values in the range "
+                 "(%g, %g) [m]", (long long)nuse, VISIR_WAVELEN_QC_MIN,
+                 VISIR_WAVELEN_QC_MAX);
+
     /* Compute mean and stdev of the sensitivity signal
-       - ignore first and last npix_ignore elements */
+       - using the selected range of elements */
     /* FIXME: Use cpl_table_select() */
     /* sens_ignore will _not_ be modified */
     IRPLIB_DIAG_PRAGMA_PUSH_IGN(-Wcast-qual);
-    sens_ignore = cpl_vector_wrap( npix - 2*npix_ignore, (double*)
+    sens_ignore = cpl_vector_wrap( nuse, (double*)
                                cpl_table_get_data_double_const(spc_table,
-                                                 "SENSITIVITY") + npix_ignore);
+                                                 "SENSITIVITY") + npix_start);
     IRPLIB_DIAG_PRAGMA_POP;
     skip_if(0);
 
@@ -618,9 +706,9 @@ static cpl_error_code visir_spc_sens_stat(const visir_spc_config * pconfig,
     emis_max = emis_min + pconfig->phot_emis_tol * (emis_max - emis_min);
 
     iok = 0;
-    for (i=0; i < npix - 2*npix_ignore; i++) {
+    for (cpl_size i=0; i < nuse; i++) {
       const double emis = cpl_table_get(spc_table, "SPC_EMISSIVITY",
-                                        i + npix_ignore, NULL);
+                                        i + npix_start, NULL);
 
       skip_if(0);
 
