@@ -1,7 +1,6 @@
-/* $Id: visir_spectro.h,v 1.70 2013-05-13 16:04:54 jtaylor Exp $
- *
+/*
  * This file is part of the VISIR Pipeline
- * Copyright (C) 2002,2003 European Southern Observatory
+ * Copyright (C) 2002,2003,2015,2016 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02111-1307  USA
  */
 
-/*
- * $Author: jtaylor $
- * $Date: 2013-05-13 16:04:54 $
- * $Revision: 1.70 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifndef VISIR_SPECTRO_H
 #define VISIR_SPECTRO_H
 
@@ -32,12 +24,14 @@
                                    Includes
  -----------------------------------------------------------------------------*/
 
-#include <cpl.h>
-
-#include "irplib_framelist.h"
 #include "visir_spc_optmod.h"
 #include "visir_inputs.h"
+#include "irplib_framelist.h"
+#include <cpl.h>
 
+/* approximate pixel position of 8um and 13 um on aquarius */
+#define VISIR_AQU_APPROX_WLEN8 140
+#define VISIR_AQU_APPROX_WLEN13 840
 
 typedef struct {
     const char * recipename;
